@@ -1,5 +1,5 @@
 package Business::AuthorizeNet::CIM;
-$Business::AuthorizeNet::CIM::VERSION = '0.13';
+$Business::AuthorizeNet::CIM::VERSION = '0.14';
 
 # ABSTRACT: Authorize.Net Customer Information Manager (CIM) Web Services API
 
@@ -522,7 +522,9 @@ sub getCustomerProfile {
 }
 
 sub getCustomerPaymentProfileRequest {
-    my ( $self, $customerProfileId, $customerPaymentProfileId ) = @_;
+    my ( $self, $customerProfileId, $customerPaymentProfileId,
+        $unmaskExpirationDate )
+      = @_;
 
     my $xml;
     my $writer = XML::Writer->new( OUTPUT => \$xml );
@@ -535,6 +537,8 @@ sub getCustomerPaymentProfileRequest {
     $writer->dataElement( 'customerProfileId', $customerProfileId );
     $writer->dataElement( 'customerPaymentProfileId',
         $customerPaymentProfileId );
+    $writer->dataElement( 'unmaskExpirationDate', 'true' )
+      if $unmaskExpirationDate;
     $writer->endTag('getCustomerPaymentProfileRequest');
 
     $xml = '<?xml version="1.0" encoding="utf-8"?>' . "\n" . $xml;
@@ -844,7 +848,7 @@ Business::AuthorizeNet::CIM - Authorize.Net Customer Information Manager (CIM) W
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -1167,9 +1171,10 @@ Retrieve an existing customer profile along with all the associated customer pay
 
 =head3 getCustomerPaymentProfileRequest
 
-Retrieve a customer payment profile for an existing customer profile.
+Retrieve a customer payment profile for an existing customer profile. $unmaskExpirationDate is an optional boolean arg, if passed
+a true value it will return the expiration date in YYYY-MM format, else it will mask as XXXX.
 
-    $cim->getCustomerPaymentProfileRequest($customerProfileId, $customerPaymentProfileId);
+    $cim->getCustomerPaymentProfileRequest($customerProfileId, $customerPaymentProfileId, $unmaskExpirationDate);
 
 =head3 getCustomerShippingAddressRequest
 
@@ -1312,7 +1317,7 @@ Olaf Alders
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Fayland Lam.
+This software is copyright (c) 2016 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
